==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Arc/ArcTPR/ts/ArcTPR_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>ArcTPR</name>
    <message>
        <location filename="../ArcTPR.js" line="+79"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Point on arc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Choose solution</source>
        <translation type="unfinished">选择解决方案</translation>
    </message>
    <message>
        <location line="+123"/>
        <location line="+65"/>
        <source>No solution</source>
        <translation type="unfinished">没有解决方案</translation>
    </message>
    <message>
        <location filename="../ArcTPR.ui" line="+17"/>
        <source>Radius:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ArcTPRInit.js" line="+2"/>
        <source>&amp;Tangent, Point, Radius</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc tangential to entity, through point with radius</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Circle2TP</name>
    <message>
        <source>First line, arc or circle</source>
        <translation type="vanished">第一条线、弧线或圆</translation>
    </message>
    <message>
        <source>Second line, arc or circle</source>
        <translation type="vanished">第二条线、弧线或圆</translation>
    </message>
    <message>
        <source>Point on circle line</source>
        <translation type="vanished">圆弧线上的点</translation>
    </message>
    <message>
        <source>Choose solution</source>
        <translation type="vanished">选择解决方案</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="vanished">没有解决方案</translation>
    </message>
    <message>
        <source>Point, 2 Tan&amp;gents</source>
        <translation type="vanished">点、两个切线(&amp;g)</translation>
    </message>
    <message>
        <source>Draw circle tangential to two entities, through point</source>
        <translation type="vanished">按点向2个实体画圆弧切线</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Arc/ArcTPR/ts/ArcTPR_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>ArcTPR</name>
    <message>
        <location filename="../ArcTPR.js" line="+79"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>选择直线，弧，圆或者椭圆</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Point on arc</source>
        <translation>弧上的点</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Choose solution</source>
        <translation>选择方案</translation>
    </message>
    <message>
        <location line="+123"/>
        <location line="+65"/>
        <source>No solution</source>
        <translation>无方案</translation>
    </message>
    <message>
        <location filename="../ArcTPR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>半径：</translation>
    </message>
    <message>
        <location filename="../ArcTPRInit.js" line="+2"/>
        <source>&amp;Tangent, Point, Radius</source>
        <translation>相切，点，半径(&amp;T)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc tangential to entity, through point with radius</source>
        <translation>以点和半径在已有实体上画相切弧</translation>
    </message>
</context>
<context>
    <name>Circle2TP</name>
    <message>
        <source>First line, arc or circle</source>
        <translation type="vanished">第一条直线、弧或圆</translation>
    </message>
    <message>
        <source>Second line, arc or circle</source>
        <translation type="vanished">第二条直线、弧或圆</translation>
    </message>
    <message>
        <source>Point on circle line</source>
        <translation type="vanished">圆上的点</translation>
    </message>
    <message>
        <source>Choose solution</source>
        <translation type="vanished">选择方案</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="vanished">无方案</translation>
    </message>
    <message>
        <source>Point, 2 Tan&amp;gents</source>
        <translation type="vanished">点、双切线(&amp;g)</translation>
    </message>
    <message>
        <source>Draw circle tangential to two entities, through point</source>
        <translation type="vanished">过点向2个实体画相切弧</translation>
    </message>
</context>
</TS>
